The actix prelude for library developers
The purpose of this module is to alleviate imports of many common actix traits by adding a glob import to the top of actix heavy modules:
use actix::dev::*;Re-exports
Modules
Structs
RecipientRequest is a Future which represents asynchronous message
sending process.Request is a Future which represents asynchronous message sending
process.Traits
Trait which defines message response
Trait defines message response channel
Converter trait, packs message to suitable envelope